@@ -490,13 +490,6 @@ if [ -d /etc/apt/apt.conf.d ] ; then
     cp -a /etc/apt/apt.conf.d/* $VROOTDIR/$VHOST/etc/apt/apt.conf.d/ > /dev/null 2>&1
 fi
 
-# This old uname was putting the name of the *host* into the vserver motd
-# uname -a > $VROOTDIR/$VHOST/etc/motd
-
-# Create a shorter motd (uname -a would give name of host-server)
-echo "Debian GNU/Linux ($DIST/$(uname -m)) $VHOST.$VDOMAIN" \
-    > "$VROOTDIR/$VHOST/etc/motd"
-
 # Create a dummy fstab
 cat << EOF > "$VROOTDIR/$VHOST/etc/fstab"
 # /etc/fstab: static file system information.
