@@ -376,14 +376,6 @@ fi
 #(echo search $VDOMAIN ; grep '^nameserver' /etc/resolv.conf) \
 #    > "$VROOTDIR/$VHOST/etc/resolv.conf"
 
-# This old uname was putting the name of the *host* into the vserver motd
-# uname -a > $VROOTDIR/$VHOST/etc/motd
-
-# Create a shorter motd (uname -a would give name of host-server)
-mv "$VROOTDIR/$VHOST/etc/motd" "$VROOTDIR/$VHOST/etc/motd.backup"
-echo "Debian GNU/Linux ($DIST/$(uname -m)) $VHOST.$VDOMAIN" \
-    > "$VROOTDIR/$VHOST/etc/motd"
-
 # Create a dummy fstab
 cat << EOF > "$VROOTDIR/$VHOST/etc/fstab"
 # /etc/fstab: static file system information.
